<li>
  <div class="post-front">
    <h2><a href="{{ url("posts." + post.slug) }}">{{ post.title }}</a></h2>
    <span>{{ date_to_string(post.date) }}</span>
    <span style='float:right'>
      Tags:
        {% for tag in post.tags %}
        {% set filtered_tags = site.tags|selectattr('slug', 'equalto', tag)|list %}
        {% if filtered_tags|length > 0 %}
        <a href="{{ url("tags." + tag + ".1") }}">{{ (filtered_tags|first).name }}</a>
        {% endif %}
        {% endfor %}
    </span>
    <p>{{ post.short_content }}</p>
  </div>
</li>
<hr>
