*, ::before, ::after{
  box-sizing: border-box;
}

html{
  height: 100%;
  font-size: 115%;
}

body{
  margin: 0px;
  display: flex;
  flex-direction: column;
  min-height: 100%;
  font-size: 1rem;
  font-family: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,"Noto Sans",sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol","Noto Color Emoji";
  font-weight: 400;
  line-height: 1.5;
}

h1, h2, h3, h4, h5, h6{
  margin-top: 0;
  margin-bottom: .5rem;
  font-weight: 500;
  line-height: 1.2;
}

h1{
  font-size: 2.5rem;
}

h2{
  font-size: 2rem;
}


a{
  text-decoration: none;
}

a:hover{
  text-decoration: underline;
}

a, a:hover{
  color: black;
}

.main-content{
  margin-top: 2rem;
  width: 100%;
  margin-left: auto;
  margin-right: auto;
  padding-left: 1rem;
  padding-right: 1rem;
  max-width: 1180px;
}







.container{
  width: 100%;
  margin-left: auto;
  margin-right: auto;
  padding-left: 15px;
  padding-right: 15px;
}

.container{
  max-width: 1140px;
}

.col-lg-12, .col-lg-9, .col-lg-8, .col-lg-6, .col-lg-4, .col-lg-3,
.col-md-12, .col-md-9, .col-md-8, .col-md-6, .col-md-4, .col-md-3,
.col-sm-12, .col-sm-9, .col-sm-8, .col-sm-6, .col-sm-4, .col-sm-3{
  max-width: 100%;
  position: relative;
  padding-left: 15px;
  padding-right: 15px;
  max-width: 100%;
  flex: 0 0 100%;
}

@media(min-width: 576px){
  /* .container{
    max-width: 540px;
  } */
  .col-sm-12{
    max-width: 100%;
    flex: 0 0 100%;
  }
  .col-sm-9{
    max-width: 75%;
    flex: 0 0 75%;
  }
  .col-sm-8{
    max-width: 66.66%;
    flex: 0 0 66.66%;
  }
  .col-sm-6{
    max-width: 50%;
    flex: 0 0 50%;
  }
  .col-sm-4{
    max-width: 33.33%;
    flex: 0 0 33.33%;
  }
  .col-sm-3{
    max-width: 25%;
    flex: 0 0 25%;
  }
}

@media(min-width: 768px){
  /* .container{
    max-width: 720px;
  } */
  .col-md-12{
    max-width: 100%;
    flex: 0 0 100%;
  }
  .col-md-9{
    max-width: 75%;
    flex: 0 0 75%;
  }
  .col-md-8{
    max-width: 66.66%;
    flex: 0 0 66.66%;
  }
  .col-md-6{
    max-width: 50%;
    flex: 0 0 50%;
  }
  .col-md-4{
    max-width: 33.33%;
    flex: 0 0 33.33%;
  }
  .col-md-3{
    max-width: 25%;
    flex: 0 0 25%;
  }
}


@media(min-width: 992px){
  /* .container{
    max-width: 960px;
  } */
  .col-lg-12{
    max-width: 100%;
    flex: 0 0 100%;
  }
  .col-lg-9{
    max-width: 75%;
    flex: 0 0 75%;
  }
  .col-lg-8{
    max-width: 66.66%;
    flex: 0 0 66.66%;
  }
  .col-lg-6{
    max-width: 50%;
    flex: 0 0 50%;
  }
  .col-lg-4{
    max-width: 33.33%;
    flex: 0 0 33.33%;
  }
  .col-lg-3{
    max-width: 25%;
    flex: 0 0 25%;
  }
}












.p0{
  padding-left: 0;
  padding-right: 0;
}

.card{
  border: 1px solid black;
  border-radius: 1rem;
  padding: 1rem;
  margin: 0.5rem;
}

.button{
  display: inline-block;
  border: 1px solid;
  padding: .375rem .75rem;
}

a.button{
  text-decoration: none;
}

.button.disabled{
  opacity: 0.65;
  background-color: transparent;
}

.navbar{
  padding: .5rem 1rem;
}

.footer{
  margin-top: auto;
  padding: .5rem 1rem;
}

.flex{
  display: flex;
  flex-wrap: wrap;
}

.row{
  display: flex;
  flex-wrap: wrap;
  margin-left: -15px;
  margin-right: -15px;
}

.fixed-top{
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
}
